==> mappingkit-6.x-1.0.tar.gz: mappingkit/serializer.php <==
<?php
// $Id: serializer.php,v 1.1.2.2 2008/07/02 08:24:43 openwereld Exp $

/**
 * Script to write incoming data to a (temporary) file and return a
 * (relative) web path to it.
 */

// Set save directory.  This should be set to a writable, web-accessible 
// directory, relative to the drupal installation

$base_path = $_GET['base_path'];
$file_directory_temp = $_GET['file_directory_temp'];

// remove base_path from this script_filename
$script_name = substr($_SERVER['SCRIPT_NAME'], strlen($base_path));
$temp_filepath = str_replace($script_name, $file_directory_temp, $_SERVER['SCRIPT_FILENAME']) . '/';
$temp_webpath = $base_path . $file_directory_temp . '/';

// Read in data.
//$data = $GLOBALS["HTTP_RAW_POST_DATA"];
$data = $_POST['postBody'];

// Create temp file
$tmpfname = tempnam($temp_filepath, "dmk");

// save data to it
$handle = fopen($tmpfname, "w");
fwrite($handle, $data);
fclose($handle);

// rename to .xml
$ext = '.'. (isset($_GET['ext']) ? $_GET['ext'] : 'xml');
if (rename($tmpfname, $tmpfname . $ext)) {
  $tmpfname .= $ext;
}

if (isset($_GET['format']) && $_GET['format'] == 'xml') {
  // Send xml content type header.
  header("Content-type: text/xml");
  
  // Return fileUrl in XML
  echo '
  <XmlSerializer xmlns:xlink="http://www.w3.org/1999/xlink">
    <OnlineResource xlink:type="simple" xlink:href="' 
    . $temp_webpath . basename($tmpfname)
    . '"/>
  </XmlSerializer>';
}
else {
  // Send xml content type header.
  header("Content-type: text/plain");
  
  // return json fileUrl
  echo '{ fileUrl: "'. $temp_webpath . basename($tmpfname) .'"}';
}

==> mappingkit-6.x-1.2.tar.gz: mappingkit/serializer.php <==
<?php
// $Id: serializer.php,v 1.1.2.3 2008/11/01 20:25:18 openwereld Exp $

/**
 * Script to write incoming data to a (temporary) file and return a
 * (relative) web path to it.
 */

// Set save directory.  This should be set to a writable, web-accessible 
// directory, relative to the drupal installation

$base_path = $_GET['base_path'];
$file_directory_temp = $_GET['file_directory_temp'];

// remove base_path from this script_filename
$script_name = substr($_SERVER['SCRIPT_NAME'], strlen($base_path));
$temp_filepath = str_replace($script_name, $file_directory_temp, str_replace("\\", "/", $_SERVER['SCRIPT_FILENAME'])) . '/';
$temp_webpath = $base_path . $file_directory_temp . '/';

// Read in data.
//$data = $GLOBALS["HTTP_RAW_POST_DATA"];
$data = $_POST['postBody'];

// Create temp file
$tmpfname = tempnam($temp_filepath, "dmk");

// save data to it
$handle = fopen($tmpfname, "w");
fwrite($handle, $data);
fclose($handle);

// rename to .xml
$ext = '.'. (isset($_GET['ext']) ? $_GET['ext'] : 'xml');
if (rename($tmpfname, $tmpfname . $ext)) {
  $tmpfname .= $ext;
}

if (isset($_GET['format']) && $_GET['format'] == 'xml') {
  // Send xml content type header.
  header("Content-type: text/xml");
  
  // Return fileUrl in XML
  echo '
  <XmlSerializer xmlns:xlink="http://www.w3.org/1999/xlink">
    <OnlineResource xlink:type="simple" xlink:href="' 
    . $temp_webpath . basename($tmpfname)
    . '"/>
  </XmlSerializer>';
}
else {
  // Send xml content type header.
  header("Content-type: text/plain");
  
  // return json fileUrl
  echo '{ fileUrl: "'. $temp_webpath . basename($tmpfname) .'"}';
}
